/********************************************************************************
 * Copyright (c) 2004, Cha Zhang <czhang@ieee.org>, Advanced Multimedia 
 * Processing Lab, ECE, Carnegie Mellon University. 
 * All rights reserved. 
 * 
 * History
 * -------
 *
 * 2004.5.15 Created by Cha Zhang at CMU as a simplified version of the
 *           rendering algorithm implemented for the mobile camera array
 *           at AMP Lab, ECE, Carnegie Mellon University. 
 ********************************************************************************/

/********************************************************************************
 * This is the header file defining the calibration parameter structure. 
 ********************************************************************************/

#ifndef __CZ_CALIBRATION_UTILS_H__
#define __CZ_CALIBRATION_UTILS_H__

#include "cz_math_utils.h"

// here we try to be consistent with the matlab calibration toolbox by Jean-Yves Bouguet 
typedef struct czsCalibParaStruct
{
    double fc[2]; 
    double cc[2]; 
    double alpha_c; 
    // lens distortion is: 
    // x' = x*(1+kc[0]*r^2+kc[1]*r^4+kc[4]*r^6) + 2*kc[2]*x*y+kc[3]*(r^2+2*x^2); 
    // y' = y*(1+kc[0]*r^2+kc[1]*r^4+kc[4]*r^6) + kc[2]*(r^2+2*y^2)+2*kc[3]*x*y; 
    //            radial distortion                    tangential distortion
    // set appropiete kc to be zero for simplified model 
    double kc[5]; 
    czsVec3 T;      // translation vector
    czsMat3 R;      // rotation matrix 
    // internal matrix is: 
    //      | fc[0]     alpha_c*fc[0]   cc[0] |
    //      | 0         fc[1]           cc[1] |
    //      | 0         0               1     | 
    // external matrix is: 
    //      | R[0]   R[1]   R[2]   T[0] | 
    //      | R[3]   R[4]   R[5]   T[1] | 
    //      | R[6]   R[7]   R[8]   T[2] | 
    
    // if there is no lens distortion, we may merge the internal and external matrix into a single 3x4 matrix 
    int no_lens_distortion;         // set it to 1 if there is no lens distortion 
    czsMat3x4 P;                    // the merged 3x4 matrix 

    czsPt3 ctr;     // camera center of projection 
} czsCalibPara; 

#endif
