/********************************************************************************
 * Copyright (c) 2004, Cha Zhang <czhang@ieee.org>, Advanced Multimedia 
 * Processing Lab, ECE, Carnegie Mellon University. 
 * All rights reserved. 
 * 
 * History
 * -------
 *
 * 2004.5.15 Created by Cha Zhang at CMU as a simplified version of the
 *           rendering algorithm implemented for the mobile camera array
 *           at AMP Lab, ECE, Carnegie Mellon University. 
 ********************************************************************************/

/********************************************************************************
 * This is the header file for quaternion camera. 
 ********************************************************************************/

#ifndef __CZ_QUATCAMERA_UTILS_H__
#define __CZ_QUATCAMERA_UTILS_H__

#include "cz_math_utils.h"

typedef struct czsQuatCameraStruct 
{
    czsPt3  pos; 
    double  fov; 
    double  rot_angle; 
    czsVec3 rot_axis; 

    czsPt3  init_pos; 
    double  init_rot_angle; 
    czsVec3 init_rot_axis; 
    double  init_fov; 
} czsQuatCam; 

// get the current quaternion 
extern void czfQuatCamGet(const czsQuatCam &qcam, czsQuat &q); 
// set the current quaternion 
extern void czfQuatCamSet(czsQuatCam &qcam, const czsQuat &q); 
// set the initial parameters 
extern void czfQuatCamSetInit(czsQuatCam &qcam, const czsPt3 &pos, const double rotangle, const czsVec3 &rotaxis, const double fov); 
// reset to inital values 
extern void czfQuatCamReset(czsQuatCam &qcam); 
// based on the quaternion, set the OpenGL matrices 
extern void czfQuatCamSetGLMat(const czsQuatCam &qcam, const double znear, const double zfar, const double width, const double height); 
// get orthogonal directions from the quaternion camera
extern void czfQuatCamGetOrthoDirs(const czsQuatCam &qcam, czsVec3 &viewdir, czsVec3 &updir, czsVec3 &rightdir); 
// translate 
extern void czfQuatCamTranslate(czsQuatCam &qcam, const double dx, const double dy, const double dz); 
// rotate
extern void czfQuatCamRotate(czsQuatCam &qcam, const czsQuat &q, const double rotdist); 
// zoom 
extern void czfQuatCamZoom(czsQuatCam &qcam, const double logzoom); 

#endif
